<?php



use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if(!defined('ABSPATH')) exit;


class BlogPost extends Widget_Base{

	public function get_name(){
		return "blogpost";
	}
	
	public function get_title(){
		return "Blog Post";
	}
	
	public function get_icon(){
		return "eicon-table-of-contents";
	}
	public function get_categories(){
		return ['techtime-category'];
	}

    public function get_categories_list(){
        $categories = array();

        $categories['none'] = __( 'None', 'dreamit-elementor-extension' );
        $taxonomy = 'category';
        $tax_terms = get_terms( $taxonomy );
        if ( ! empty( $tax_terms ) && ! is_wp_error( $tax_terms ) ){
            foreach( $tax_terms as $item ) {
                $categories[$item->term_id] = $item->name;
            }
        }
        return $categories;
    }	
	
	protected function _register_controls(){
		

		$this->start_controls_section(
			'query_section',
			[
				'label' => __( 'Query & Layout', 'dreamit-elementor-extension' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'select_style',
			[
				'label' => __( 'Select Style', 'techtime-elementor-extension' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'one' => __( 'Default', 'techtime-elementor-extension' ),
					'two' => __( 'Carousel', 'techtime-elementor-extension' ),
				],
				'default' => 'one',				
			]
		);

		$this->add_control(
            'category_ids',
            [
                'label' => __( 'Select By Category', 'dreamit-elementor-extension' ),
                'type' => Controls_Manager::SELECT2,
                'multiple'    => true,
                'default' => '',
                'options'   => $this->get_categories_list()
            ]
        );

		// Blog Column
		$this->add_responsive_control(
			'blog_column', [
				'label' => esc_html__( 'Select Column', 'dreamit-elementor-extension' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'col-md-4',
				'dynamic' => [
					'active' => true,
				],
				'options' => [
					'col-lg-4 col-md-6'  => esc_html__( '3 Column', 'dreamit-elementor-extension' ),
					'col-lg-6 col-md-6' => esc_html__( '2 Column', 'dreamit-elementor-extension' ),
					'col-lg-3 col-md-4' => esc_html__( '4 Column', 'dreamit-elementor-extension' ),
				],
				'condition'=>[
					'select_style'=> 'one',
				], 
			]
		);

		$this->add_control(
			'blog_posts', [
				'label' => esc_html__( 'Total Posts', 'dreamit-elementor-extension' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'default' => 3,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'button_section',
			[
				'label' => __( 'Button', 'techtime-elementor-extension' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
			$this->add_control(
				'button_text',
				[
					'label' => __( 'Button Text', 'techtime-elementor-extension' ),
					'type' => Controls_Manager::TEXT,
					'dynamic' => [
						'active' => true,
					],
					'placeholder' => __( 'Enter your button text', 'techtime-elementor-extension' ),
					'label_block' => true,
					'default' => __( 'Read More', 'techtime-elementor-extension' ),
				]
			);
			$this->add_control(
				'show_button',
				[
					'label' => __( 'Show Button', 'techtime-elementor-extension' ),
					'type' => Controls_Manager::SWITCHER,
					'label_on' => __( 'Show', 'techtime-elementor-extension' ),
					'label_off' => __( 'Hide', 'techtime-elementor-extension' ),
					'return_value' => 'yes',
					'default' => 'yes',
				]
			);
			$this->add_control(
				'button_icon',
				[
					'label' => __( 'Button Icon', 'techtime-elementor-extension' ),
					'type' => Controls_Manager::ICONS,
					'default' => [
						'value' => 'fa fa-angle-right',
						'library' => 'solid',
					],
				]
			);
		$this->end_controls_section();

/*
==========
Style Tab
==========
*/


		$this->start_controls_section(
			'meta_section_style',
			[
				'label' => __( 'Post Meta', 'techtime-elementor-extension' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
			$this->add_control(
				'meta_color',
				[
					'label' => __( 'Color', 'techtime-elementor-extension' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .techtime-blog-meta-left a' => 'color: {{VALUE}};',
						'{{WRAPPER}} .techtime-blog-meta-left span' => 'color: {{VALUE}};',
					],
				]
			);
			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'meta_typography',
					'selector' => '{{WRAPPER}} .techtime-blog-meta-left a, {{WRAPPER}} .techtime-blog-meta-left span',
				]
			);
		$this->end_controls_section();

		$this->start_controls_section(
			'title_section_style',
			[
				'label' => __( 'Title', 'techtime-elementor-extension' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'title_color',
				[
					'label' => __( 'Color', 'techtime-elementor-extension' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .blog-page-title_adn h2 a' => 'color: {{VALUE}};',
					],
				]
			);
			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'title_typography',
					'selector' => '{{WRAPPER}} .blog-page-title_adn h2 a, {{WRAPPER}} .elementor-icon-box-content .elementor-icon-box-title a',
				]
			);
			$this->add_responsive_control(
				'title_margin',
				[
					'label' => __( 'Margin', 'techtime-elementor-extension' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .blog-page-title_adn h2' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'description_section_style',
			[
				'label' => __( 'Description', 'techtime-elementor-extension' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'description_color',
				[
					'label' => __( 'Color', 'techtime-elementor-extension' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .blog-content_adn p' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'description_typography',
					'selector' => '{{WRAPPER}} .blog-content_adn p',
				]
			);
			$this->add_responsive_control(
				'description_margin',
				[
					'label' => __( 'Margin', 'techtime-elementor-extension' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .blog-content_adn p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
		$this->end_controls_section();

		$this->start_controls_section(
			'button_style',
			[
				'label' => __( 'Button Style', 'techtime' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'btn_color',
				[
					'label' => __( 'Color', 'techtime' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .techtime-blog-readmore a' => 'color: {{VALUE}}',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'box_section_style',
			[
				'label' => __( 'Box', 'techtime-elementor-extension' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

			$this->start_controls_tabs(
				'box_style_tabs'
			);
				$this->start_controls_tab(
					'box_style_normal_tab',
					[
						'label' => __( 'Normal', 'techtime-elementor-extension' ),
					]
				);
				
					$this->add_group_control(
						\Elementor\Group_Control_Border::get_type(),
						[
							'name' => 'box_border',
							'label' => __( 'Border', 'techtime-elementor-extension' ),
							'selector' => '{{WRAPPER}} .techtime-single-blog_adn',
						]
					);

					$this->add_responsive_control(
						'box_border_radius',
						[
							'label' => __( 'Border Radius', 'techtime-elementor-extension' ),
							'type' => \Elementor\Controls_Manager::DIMENSIONS,
							'size_units' => [ 'px', 'em', '%' ],
							'selectors' => [
								'{{WRAPPER}} .techtime-single-blog_adn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							],
						]
					);
						$this->add_group_control(
						\Elementor\Group_Control_Box_Shadow::get_type(),
						[
							'name' => 'box_shadow',
							'label' => __( 'Box Shadow', 'techtime-elementor-extension' ),
							'selector' => '{{WRAPPER}} .techtime-single-blog_adn',
						]
					);

					$this->add_group_control(
						\Elementor\Group_Control_Background::get_type(),
						[
							'name' => 'box_background',
							'label' => __( 'Background', 'techtime-elementor-extension' ),
							'types' => [ 'classic', 'gradient', 'video' ],
							'selector' => '{{WRAPPER}} .techtime-single-blog_adn',
						]
					);
				
				$this->end_controls_tab();
				
				$this->start_controls_tab(
					'box_style_hover_tab',
					[
						'label' => __( 'Hover', 'techtime-elementor-extension' ),
					]
				);
						$this->add_group_control(
						\Elementor\Group_Control_Border::get_type(),
						[
							'name' => 'hover_box_border',
							'label' => __( 'Border', 'techtime-elementor-extension' ),
							'selector' => '{{WRAPPER}} .techtime-single-blog_adn:hover',
						]
					);

					$this->add_responsive_control(
						'hover_box_border_radius',
						[
							'label' => __( 'Border Radius', 'techtime-elementor-extension' ),
							'type' => \Elementor\Controls_Manager::DIMENSIONS,
							'size_units' => [ 'px', 'em', '%' ],
							'selectors' => [
								'{{WRAPPER}} .techtime-single-blog_adn:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							],
						]
					);

					$this->add_group_control(
						\Elementor\Group_Control_Box_Shadow::get_type(),
						[
							'name' => 'hover_box_shadow',
							'label' => __( 'Box Shadow', 'techtime-elementor-extension' ),
							'selector' => '{{WRAPPER}} .techtime-single-blog_adn:hover',
						]
					);
						$this->add_group_control(
						\Elementor\Group_Control_Background::get_type(),
						[
							'name' => 'hover_box_background',
							'label' => __( 'Background', 'techtime-elementor-extension' ),
							'types' => [ 'classic', 'gradient', 'video' ],
							'selector' => '{{WRAPPER}} .techtime-single-blog_adn:hover',
						]
					);
				
				$this->end_controls_tab();
				
			$this->end_controls_tabs();

			$this->add_responsive_control(
				'box_margin',
				[
					'label' => __( 'Margin', 'techtime-elementor-extension' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .techtime-single-blog_adn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
					'separator' => 'before',
				]
			);
			$this->add_responsive_control(
				'box_padding',
				[
					'label' => __( 'Padding', 'techtime-elementor-extension' ),
					'type' => Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .techtime-single-blog_adn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
		$this->end_controls_section();
	}

	protected function render() {

		$settings = $this->get_settings_for_display();

		$blog_column = $settings['blog_column'];
		$blog_posts = $settings['blog_posts'];
		$cats = $settings['category_ids'];

		if($blog_column == 'col-lg-4 col-md-6') {
			$blog_column = 'col-lg-4 col-md-6';
		} elseif($blog_column == 'col-lg-6 col-md-6'){
			$blog_column = 'col-lg-6 col-md-6';
		} elseif($blog_column == 'col-lg-3 col-md-4'){ 
			$blog_column = 'col-lg-3 col-md-4';			
		}
		
		if($cats){
            if( is_array($cats) && count($cats) > 0 ){
                $field_name = is_numeric($cats[0]) ? 'term_id':'slug';
                $query_args['tax_query'] = array(
                    array(
                      'taxonomy' => 'category',
                      'terms' => $cats,
                      'field' => $field_name,
                      'include_children' => false
                    )
                );
            }
        }


		?>

        <?php if($settings['select_style']=='one'){ ?>

			<div class="row">				
				
				<?php
					$args = [
						'post_type' => 'post',
						'cat' => $cats,
						'posts_per_page' => $blog_posts,
					];
					$query = new WP_Query($args);
					while($query->have_posts()) {
						$query->the_post();
				?>

				<!-- single blog -->
					<div class="<?php echo $blog_column; ?>">
						<div class="single_blog_adn">
							<div id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
								<div class="ttech-single-blog_adn">

									<!-- BLOG THUMB -->
									<div class="ttech-blog-thumb_adn">
										<a href="<?php the_permalink(); ?>"><?php the_post_thumbnail(''); ?></a>
										<a class="thumb-icon" href="<?php the_permalink(); ?>"><i class="flaticon-add"></i></a>

									</div>		
									<div class="ttech-blog-meta-top">
											<?php the_category();?>
											<a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ); ?>"><i aria-hidden="true" class="far fa-user"></i> <?php the_author(); ?></a>
											<span><i aria-hidden="true" class="far fa-calendar-alt"></i> <?php echo get_the_time(get_option('date_format')); ?></span>
										</div>							
									<!-- BLOG CONTENT -->
									<div class="em-blog-content-area_adn">
										<!-- BLOG TITLE -->
										<div class="blog-page-title_adn">
											<h2><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>			
										</div>
										<!-- BLOG BUTTON -->
										<?php if( 'yes'===$settings['show_button'] ){ ?>
											<div class="techtime-blog-readmore">
												<a href="<?php the_permalink(); ?>" class="learn_btn">
												<?php echo $settings['button_text']; ?>
												<?php \Elementor\Icons_Manager::render_icon( $settings['button_icon'], [ 'aria-hidden' => 'true' ] ); ?></a>
											</div>
										<?php } ?>
									</div><!-- .em-blog-content-area_adn -->
									
								</div>
							
							</div> <!--  END SINGLE BLOG -->

								
						</div>
					
					</div>
				<?php
				}
				wp_reset_postdata();

				?>
					
			</div>
		
		<?php }elseif($settings['select_style']=='two'){ ?>			

			<div class="blog_style_two">				
				<div class="blog_wrap blog_carousel owl-carousel owl-loaded curosel-style">
					<?php
						$args = [
							'post_type' => 'post',
							'cat' => $cats,
							'posts_per_page' => $blog_posts,
						];
						$query = new WP_Query($args);
						while($query->have_posts()) {
						$query->the_post();
					?>
					<!-- single blog -->
					<div class="col-md-12" >
						<div class="single_blog_adn">
							<div id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
								<div class="techtime-single-blog_adn ">

									<!-- BLOG THUMB -->
									
									<div class="techtime-blog-thumb_adn ">
										<a href="<?php the_permalink(); ?>"><?php the_post_thumbnail('techtime-blog-default'); ?></a>
										<div class="techtime-blog-meta-top">
											<?php the_category();?>
										</div>
									</div>									
									<!-- BLOG CONTENT -->
									<div class="em-blog-content-area_adn ">
										<div class="techtime-blog-meta-left">
											<i aria-hidden="true" class="far fa-user"></i>	 
											<a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ); ?>">
											<?php the_author(); ?>
											</a>
											<span><i aria-hidden="true" class="far fa-calendar-alt"></i><?php echo get_the_time(get_option('date_format')); ?></span>
										</div>
										<!-- BLOG TITLE -->
										<div class="blog-page-title_adn ">
											<h2><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>	
										</div>
										<!-- BLOG CONTENT -->
										<div class="blog-inner_adn ">
											<div class="blog-content_adn ">					
												<p><?php echo wp_trim_words( get_the_content(), 12, ' ' ); ?></p>
											</div>
										</div>	
										<!-- BLOG BUTTON -->
										<?php if( 'yes'===$settings['show_button'] ){ ?>
										<div class="techtime-blog-readmore">
											<a href="<?php the_permalink(); ?>" class="learn_btn">
											<?php echo $settings['button_text']; ?>
											<?php \Elementor\Icons_Manager::render_icon( $settings['button_icon'], [ 'aria-hidden' => 'true' ] ); ?></a>
										</div>
										<?php } ?>
										
									</div><!-- .em-blog-content-area_adn -->
									
								</div>
							
							</div> <!--  END SINGLE BLOG -->

								
						</div>
					
					</div>
					<?php } wp_reset_postdata(); ?>
					
				</div>
			</div>


    		<script>
    			jQuery(document).ready(function($) {
    				"use strict";
                	/* Blog Curousel */
                	$('.blog_carousel').owlCarousel({
                		dots: true,
                		nav: false,
                		autoplayTimeout: 10000,
                		navText: ["<i class='flaticon-left-arrow-3'></i>", "<i class='flaticon-right-arrow-3''></i>"],
                		responsive: {
                			0: {
                				items: 1
                			},
                			768: {
                				items: 2
                			},
                			992: {
                				items: 3
                			},
                			1500: {
                				items: 3
                			},
                			1920: {
                				items: 3
                			}
                		}
                	})	
            		});
            	</script>
 
		
		<?php } ?>

		<?php
	}
}