<?php



use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if(!defined('ABSPATH')) exit;


class Testimonial extends Widget_Base{

	public function get_name(){
		return "testimonial";
	}
	
	public function get_title(){
		return "Testimonial";
	}
	
	public function get_icon(){
		return "eicon-blockquote";
	}
	public function get_categories(){
		return ['techtime-category'];
	}
	
	protected function register_controls(){

		$this->start_controls_section(
			'slider', [
				'label' => __( 'Slider', 'techtime-elementor-extension' ),
			]
		);
		$this->add_control(
			'slides', [
				'label' => __( 'Slide items', 'techtime-elementor-extension' ),
				'type' => Controls_Manager::REPEATER,
				'title_field' => '{{{name}}}',
				'fields' => [
					[
						'name'	=> 'image',
						'label' => __( 'Choose Image', 'techtime-elementor-extension' ),
						'type' => Controls_Manager::MEDIA,
						'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
					],
					
					
			[	'name'	=> 'quote_text',
						'label' => __( 'Quote', 'techtime-elementor-extension' ),
						'type' => Controls_Manager::TEXTAREA,
						'dynamic' => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Quote', 'techtime-elementor-extension' ),
						'label_block' => true,
						'default' => __( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.', 'techtime-elementor-extension' ),
					],
					[
						'name'	=> 'quote_title',
						'label' => __( 'Title', 'techtime-elementor-extension' ),
						'type' => Controls_Manager::TEXT,
						'dynamic' => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your Quote', 'techtime-elementor-extension' ),
						'label_block' => true,
						'default' => __( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.', 'techtime-elementor-extension' ),
					],
					[
						'name'	=> 'name',
						'label' => __( 'Name', 'techtime-elementor-extension' ),
						'type' => Controls_Manager::TEXT,
						'dynamic' => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your name', 'techtime-elementor-extension' ),
						'default' => __( 'Your Name', 'techtime-elementor-extension' ),
					],
					[
						'name'	=> 'designation',
						'label' => __( 'Designation', 'techtime-elementor-extension' ),
						'type' => Controls_Manager::TEXT,
						'dynamic' => [
							'active' => true,
						],
						'placeholder' => __( 'Enter your designation', 'techtime-elementor-extension' ),
						'default' => __( 'Web Developer', 'techtime-elementor-extension' ),
					],
					[
						'name'	=> 'rating',
						'label' => __( 'Rating', 'techtime-elementor-extension' ),
						'type' => Controls_Manager::NUMBER,
						'min' => 1,
						'max' => 5,
						'step' => 1,
						'default' => 3,
					],
				],
			]
		);


		$this->end_controls_section();




/*
==========
Style Tab
==========
*/

		$this->start_controls_section(
			'general_section',
			[
				'label' => __( 'General', 'techtime-elementor-extension' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'select_style',
				[
					'label' => __( 'Select Style', 'techtime-elementor-extension' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'options' => [
						'one' => __( 'One', 'techtime-elementor-extension' ),
						'two' => __( 'Two', 'techtime-elementor-extension' ),
						'three' => __( 'Three', 'techtime-elementor-extension' ),
						'four' => __( 'Four', 'techtime-elementor-extension' ),
						'five' => __( 'Five', 'techtime-elementor-extension' ),
					],
					'default' => 'one',
					
				]
			);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'quote_section',
			[
				'label' => __( 'Quote', 'techtime-elementor-extension' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				'conditions' => [
				    'relation' => 'or',
					'terms' => [
						[
			                'terms' => [
				                [
			                        'name' => 'select_style',
			                        'operator' => '==',
			                        'value' => 'one'
			                    ],
			                ]
			            ],
			            [
			                'terms' => [
			                    [
			                         'name' => 'select_style',
			                         'operator' => '==',
			                         'value' => 'three'
				                ],
			                ]
						]
					]
				]
			]
		);
    		$this->add_control(
    			'quote_text_color',
    			[
    				'label' => __( 'Text Color', 'techtime-elementor-extension' ),
    				'type' => \Elementor\Controls_Manager::COLOR,
    				'selectors' => [
    					'{{WRAPPER}} .single_testimonial .testi_content .em_testi_text' => 'color: {{VALUE}}',
    				],
    			]
    		);
    		$this->add_control(
    			'quote_background_color',
    			[
    				'label' => __( 'Background Color', 'techtime-elementor-extension' ),
    				'type' => \Elementor\Controls_Manager::COLOR,
    				'selectors' => [
    					'{{WRAPPER}} .single_testimonial .testi_content' => 'background-color: {{VALUE}}',
    					'{{WRAPPER}} .single_testimonial .testi_content::before' => 'border-left-color: {{VALUE}}; border-top-color: {{VALUE}}',
    				],
    			]
    		);
		$this->end_controls_section();

		$this->start_controls_section(
			'icon_section_style',
			[
				'label' => __( 'Icon', 'techtime-elementor-extension' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'icon_color',
				[
					'label' => __( 'Icon Color', 'techtime-elementor-extension' ),
					'type' => Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .testi_thumb:before' => 'color: {{VALUE}};',
					],
				]
			);
			
			$this->add_control(
				'icon_background_color',
				[
					'label' => __( 'Icon Background Color', 'techtime-elementor-extension' ),
					'type' => Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .testi_thumb:before' => 'background-color: {{VALUE}};',
					],
				]
			);

		$this->end_controls_section();

		$this->start_controls_section(
			'content_section_style',
			[
				'label' => __( 'Content', 'techtime-elementor-extension' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
			
			$this->add_control(
				'name_color',
				[
					'label' => __( 'Name Color', 'techtime-elementor-extension' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .testi_title h2' => 'color: {{VALUE}};',
					],
				]
			);
			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'name_typography',
					'selector' => '{{WRAPPER}} .testi_title h2',
				]
			);
			$this->add_control(
				'designation_color',
				[
					'label' => __( 'Designation Color', 'techtime-elementor-extension' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '',
					'separator' => 'before',
					'selectors' => [
						'{{WRAPPER}} .testi_title span' => 'color: {{VALUE}};',
					],
				]
			);
			
			
			
			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'title_typography',
					'selector' => '{{WRAPPER}} .testi_title',
				]
			);
			$this->add_control(
				'title_color',
				[
					'label' => __( 'Title Color', 'techtime-elementor-extension' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '',
					'separator' => 'before',
					'selectors' => [
						'{{WRAPPER}} .testi_title' => 'color: {{VALUE}};',
					],
				]
			);
			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'designation_typography',
					'selector' => '{{WRAPPER}} .testi_title span',
				]
			);

			$this->add_control(
				'quote_color',
				[
					'label' => __( 'Quote Color', 'techtime-elementor-extension' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '',
					'separator' => 'before',
					'selectors' => [
						'{{WRAPPER}} .testi_content .testi_text' => 'color: {{VALUE}};',
					],
				]
			);
			$this->add_group_control(
				\Elementor\Group_Control_Typography::get_type(),
				[
					'name' => 'quote_typography',
					'selector' => '{{WRAPPER}} .testi_content .testi_text',
				]
			);

			$this->add_control(
				'rating_color',
				[
					'label' => __( 'Rating Color', 'techtime-elementor-extension' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '',
					'separator' => 'before',
					'selectors' => [
						'{{WRAPPER}} .testi-star i.active' => 'color: {{VALUE}};',
					],
				]
			);
			
		$this->end_controls_section();
		
	}

	protected function render() {

		$settings = $this->get_settings_for_display();

		$slides = isset($settings['slides']) ? $settings['slides'] : '';

		?>
		



		<?php if($settings['select_style']=='one'){ ?>

			<div class="testimonial_list owl-carousel owl-loaded curosel-style">

				<?php foreach ($slides as $slide) { ?>
				<div class="col-md-12">	
					<div class="single_testimonial default-style">						
					<div class="testi_thumb">
							<img src="<?php echo $slide['image']['url']; ?>" alt="">
						</div>
						
						<div class="testi_title">
							<h2><?php echo $slide['name']; ?><span><?php echo $slide['designation']; ?></span></h2>
						</div>
						<div class="testi_content">
							<div class="testi_text">
								<?php echo $slide['quote_text']; ?>
							</div>
						</div>
						<div class="reviews_rating">
							<?php if( $slide['rating']==5 ){ ?>
							<div class="testi-star">
								<i class="fa fa-star active"></i>
								<i class="fa fa-star active"></i>
								<i class="fa fa-star active"></i>
								<i class="fa fa-star active"></i>
								<i class="fa fa-star active"></i>
							</div>
							<?php } ?>				
							
							<?php if( $slide['rating']==4 ){ ?>			
							<div class="testi-star">
								<i class="fa fa-star active"></i>
								<i class="fa fa-star active"></i>
								<i class="fa fa-star active"></i>
								<i class="fa fa-star active"></i>
								<i class="fa fa-star-o"></i>
							</div>												
							<?php } ?>
							
							<?php if( $slide['rating']==3 ){ ?>
							<div class="testi-star">
								<i class="fa fa-star active"></i>
								<i class="fa fa-star active"></i>
								<i class="fa fa-star active"></i>
								<i class="fa fa-star-o"></i>
								<i class="fa fa-star-o"></i>
							</div>												
							<?php } ?>
							
							<?php if( $slide['rating']==2 ){ ?>
							<div class="testi-star">
								<i class="fa fa-star active"></i>
								<i class="fa fa-star active"></i>
								<i class="fa fa-star-o"></i>
								<i class="fa fa-star-o"></i>
								<i class="fa fa-star-o"></i>
							</div>												
							<?php } ?>
							
							<?php if( $slide['rating']==1 ){ ?>
							<div class="testi-star">
								<i class="fa fa-star active"></i>
								<i class="fa fa-star-o"></i>
								<i class="fa fa-star-o"></i>
								<i class="fa fa-star-o"></i>
								<i class="fa fa-star-o"></i>
							</div>
							<?php } ?>
						</div><!-- .reviews_rating -->
					</div>
				</div>
				<?php } ?>
			</div>
            <script>
            	jQuery(document).ready(function($) {
            		"use strict";
            		$('.testimonial_list').owlCarousel({
            		loop: true,
            		autoplay: false,
            		autoplayTimeout: 10000,
            		dots: true,
            		nav: false,
            		navText: ["<i class='flaticon-back-1'></i>", "<i class='fa fa-angle-right'></i>"],
            		responsive: {
            			0: {
            				items: 1
            			},
            			768: {
            				items: 1
            			},
            			992: {
            				items: 1
            			},
            			1000: {
            				items: 1
            			},
            			1920: {
            				items: 1,
            			}
            		}
            	})
            	});
            </script>			

		<?php }elseif($settings['select_style']=='two'){ ?>


			<div class="testimonial_list2 owl-carousel owl-loaded curosel-style testimonial-style-two">												
				<?php foreach ($slides as $slide) { ?>
						<div class="single_testimonial">
													
							<div class="testi_top clearfix">
								<div class="testi_thumb">
									<img src="<?php echo $slide['image']['url']; ?>" alt="">
								</div>
								
								<div class="testi_title">
									<h2><?php echo $slide['name']; ?><span><?php echo $slide['designation']; ?></span></h2>
								</div>
							</div>
							<div class="testi_content">
								<div class="testi_text">
									<?php echo $slide['quote_text']; ?>
								</div>
								<div class="reviews_rating">
									<?php if( $slide['rating']==5 ){ ?>
										<div class="testi-star">
											<i class="fa fa-star active"></i>
											<i class="fa fa-star active"></i>
											<i class="fa fa-star active"></i>
											<i class="fa fa-star active"></i>
											<i class="fa fa-star active"></i>
										</div>
									<?php } ?>
									<?php if( $slide['rating']==4 ){ ?>			
										<div class="testi-star">
											<i class="fa fa-star active"></i>
											<i class="fa fa-star active"></i>
											<i class="fa fa-star active"></i>
											<i class="fa fa-star active"></i>
											<i class="fa fa-star-o"></i>
										</div>												
									<?php } ?>
									<?php if( $slide['rating']==3 ){ ?>
										<div class="testi-star">
											<i class="fa fa-star active"></i>
											<i class="fa fa-star active"></i>
											<i class="fa fa-star active"></i>
											<i class="fa fa-star-o"></i>
											<i class="fa fa-star-o"></i>
										</div>												
									<?php } ?>
									<?php if( $slide['rating']==2 ){ ?>
										<div class="testi-star">
											<i class="fa fa-star active"></i>
											<i class="fa fa-star active"></i>
											<i class="fa fa-star-o"></i>
											<i class="fa fa-star-o"></i>
											<i class="fa fa-star-o"></i>
										</div>												
									<?php } ?>
									<?php if( $slide['rating']==1 ){ ?>
										<div class="testi-star">
											<i class="fa fa-star active"></i>
											<i class="fa fa-star-o"></i>
											<i class="fa fa-star-o"></i>
											<i class="fa fa-star-o"></i>
											<i class="fa fa-star-o"></i>
										</div>
									<?php } ?>
								</div><!-- .reviews_rating -->
							</div>
						</div>			
				<?php } ?>								
									
			</div>
            <script>
            	jQuery(document).ready(function($) {
            		"use strict";
                	// 6.EM TESTIMONIAL
                	$('.testimonial_list2').owlCarousel({
                		loop: true,
                		autoplay: true,
                		autoplayTimeout: 10000,
                		dots: false,
                		nav: true,
						margin: 30,
                		navText: ["<i class='flaticon-back-1'></i>", "<i class='flaticon-right-arrow'></i>"],
                		responsive: {
                			0: {
                				items: 1
                			},
                			768: {
                				items: 1
                			},
                			992: {
                				items: 1
                			},
                			1000: {
                				items: 1
                			},
                			1920: {
                				items: 1,
                			}
                		}
                	})
            	});
            </script>

		<?php }elseif($settings['select_style']=='three'){ ?>

			<div class="testimonial_list3 owl-carousel owl-loaded curosel-style testimonial-style-three">												
				<?php foreach ($slides as $slide) { ?>
						<div class="single_testimonial">
													
							<div class="testi-wrpper">
								<div class="testi_top clearfix">
									<div class="testi_thumb">
										<img src="<?php echo $slide['image']['url']; ?>" alt="">
									</div>
									
									<div class="testi_title">
										<h2><?php echo $slide['name']; ?><span><?php echo $slide['designation']; ?></span></h2>
									</div>
								</div>
								<div class="testi_content">
									<div class="testi_text">
										<?php echo $slide['quote_text']; ?>
									</div>
									<div class="reviews_rating">
										<?php if( $slide['rating']==5 ){ ?>
											<div class="testi-star">
												<i class="fa fa-star active"></i>
												<i class="fa fa-star active"></i>
												<i class="fa fa-star active"></i>
												<i class="fa fa-star active"></i>
												<i class="fa fa-star active"></i>
											</div>
										<?php } ?>
										<?php if( $slide['rating']==4 ){ ?>			
											<div class="testi-star">
												<i class="fa fa-star active"></i>
												<i class="fa fa-star active"></i>
												<i class="fa fa-star active"></i>
												<i class="fa fa-star active"></i>
												<i class="fa fa-star-o"></i>
											</div>												
										<?php } ?>
										<?php if( $slide['rating']==3 ){ ?>
											<div class="testi-star">
												<i class="fa fa-star active"></i>
												<i class="fa fa-star active"></i>
												<i class="fa fa-star active"></i>
												<i class="fa fa-star-o"></i>
												<i class="fa fa-star-o"></i>
											</div>												
										<?php } ?>
										<?php if( $slide['rating']==2 ){ ?>
											<div class="testi-star">
												<i class="fa fa-star active"></i>
												<i class="fa fa-star active"></i>
												<i class="fa fa-star-o"></i>
												<i class="fa fa-star-o"></i>
												<i class="fa fa-star-o"></i>
											</div>												
										<?php } ?>
										<?php if( $slide['rating']==1 ){ ?>
											<div class="testi-star">
												<i class="fa fa-star active"></i>
												<i class="fa fa-star-o"></i>
												<i class="fa fa-star-o"></i>
												<i class="fa fa-star-o"></i>
												<i class="fa fa-star-o"></i>
											</div>
										<?php } ?>
									</div><!-- .reviews_rating -->
								</div>
							</div>
							
						</div>			
				<?php } ?>								
									
			</div>
            <script>
            	jQuery(document).ready(function($) {
            		"use strict";
            		$('.testimonial_list3').owlCarousel({
						loop: true,
                		autoplay: false,
                		autoplayTimeout: 10000,
                		dots: false,
                		nav: true,
						margin: 30,
                		navText: ["<i class='flaticon-back-1'></i>", "<i class='flaticon-right-arrow'></i>"],
                		responsive: {
            			0: {
            				items: 1
            			},
            			768: {
            				items: 1
            			},
            			992: {
            				items: 1
            			},
            			1000: {
            				items: 1
            			},
            			1920: {
            				items: 1,
            			}
            		}
            	})
            	});
            </script>			
		
		<?php }elseif($settings['select_style']=='four'){ ?>

			<div class="testimonial_list owl-carousel owl-loaded curosel-style testimonial-style-four">

				<?php foreach ($slides as $slide) { ?>
				<div class="col-md-12">	

					<div class="single_testimonial">
						<div class="testi_thumb">
							<img src="<?php echo $slide['image']['url']; ?>" alt="">
						</div>
						<div class="reviews_rating">
							<?php if( $slide['rating']==5 ){ ?>
							<div class="testi-star">
								<i class="fa fa-star active"></i>
								<i class="fa fa-star active"></i>
								<i class="fa fa-star active"></i>
								<i class="fa fa-star active"></i>
								<i class="fa fa-star active"></i>
							</div>
							<?php } ?>				
							
							<?php if( $slide['rating']==4 ){ ?>			
							<div class="testi-star">
								<i class="fa fa-star active"></i>
								<i class="fa fa-star active"></i>
								<i class="fa fa-star active"></i>
								<i class="fa fa-star active"></i>
								<i class="fa fa-star"></i>
							</div>												
							<?php } ?>
							<?php if( $slide['rating']==3 ){ ?>
							<div class="testi-star">
								<i class="fa fa-star active"></i>
								<i class="fa fa-star active"></i>
								<i class="fa fa-star active"></i>
								<i class="fa fa-star"></i>
								<i class="fa fa-star"></i>
							</div>												
							<?php } ?>
							
							<?php if( $slide['rating']==2 ){ ?>
							<div class="testi-star">
								<i class="fa fa-star active"></i>
								<i class="fa fa-star active"></i>
								<i class="fa fa-star"></i>
								<i class="fa fa-star"></i>
								<i class="fa fa-star"></i>
							</div>												
							<?php } ?>
							
							<?php if( $slide['rating']==1 ){ ?>
							<div class="testi-star">
								<i class="fa fa-star active"></i>
								<i class="fa fa-star"></i>
								<i class="fa fa-star"></i>
								<i class="fa fa-star"></i>
								<i class="fa fa-star"></i>
							</div>
							<?php } ?>
						</div><!-- .reviews_rating -->
						<div class="testi_title">
							<h2><?php echo $slide['name']; ?><span><?php echo $slide['designation']; ?></span></h2>
						</div>
						<div class="testi_content">
							<div class="testi_text">
								<?php echo $slide['quote_text']; ?>
							</div>
						</div>
					</div>
				</div>
				<?php } ?>
			</div>
            <script>
            	jQuery(document).ready(function($) {
            		"use strict";
            		$('.testimonial_list').owlCarousel({
            		loop: true,
            		autoplay: false,
            		autoplayTimeout: 10000,
            		dots: true,
            		nav: false,
            		navText: ["<i class='flaticon-back-1'></i>", "<i class='fa fa-angle-right'></i>"],
            		responsive: {
            			0: {
            				items: 1
            			},
            			768: {
            				items: 2
            			},
            			992: {
            				items: 2
            			},
            			1000: {
            				items: 3
            			},
            			1920: {
            				items: 3,
            			}
            		}
            	})
            	});
            </script>			

		<?php } elseif($settings['select_style']=='five'){ ?>


			<div class="testimonial_list2 owl-carousel owl-loaded curosel-style testimonial-style-five">												
				<?php foreach ($slides as $slide) { ?>
						<div class="single_testimonial">
						
						<div class="testi_content">
						        <div class="testi_title">
						            <?php echo $slide['quote_title']; ?>
						        </div>
								<div class="testi_text">
									<?php echo $slide['quote_text']; ?>
								</div>
								<div class="testi_top clearfix">
								<div class="single_testi_thumb d-flex align-items-center">
								<div class="testi_thumb">
									<img src="<?php echo $slide['image']['url']; ?>" alt="">
								</div>
								
								<div class="testi_title">
									<h2><?php echo $slide['name']; ?><span><?php echo $slide['designation']; ?></span></h2>
								</div>
								</div>
							</div>
							</div>
													
							
							
						</div>			
				<?php } ?>								
									
			</div>
            <script>
            	jQuery(document).ready(function($) {
            		"use strict";
                	// 6.EM TESTIMONIAL
                	$('.testimonial_list2').owlCarousel({
                		loop: true,
                		autoplay: true,
                		autoplayTimeout: 10000,
                		dots: false,
                		nav: true,
						margin: 30,
                		navText: ["<i class='flaticon-back-1'></i>", "<i class='flaticon-right-arrow'></i>"],
                		responsive: {
                			0: {
                				items: 1
                			},
                			768: {
                				items: 1
                			},
                			992: {
                				items: 1
                			},
                			1000: {
                				items: 1
                			},
                			1920: {
                				items: 1,
                			}
                		}
                	})
            	});
            </script>

		<?php }?>
							
		<?php
	}
	



}

