<?php



use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;
use Elementor\Repeater;
use Elementor\Group_Control_Box_Shadow;

if(!defined('ABSPATH')) exit;


class WorkProcess extends Widget_Base{

	public function get_name(){
		return "workprocess";
	}
	
	public function get_title(){
		return "Work Process";
	}
	
	public function get_icon(){
		return "eicon-flow";
	}

	public function get_categories(){
		return ['techtime-category'];
	}

	protected function _register_controls() {
		
		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Content', 'techtime-elementor-extension' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
			$this->add_control(
				'image',
				[
					'label' => __( 'Choose Image', 'techtime-elementor-extension' ),
					'type' => Controls_Manager::MEDIA,
					'default' => [
						'url' => \Elementor\Utils::get_placeholder_image_src(),
					],
					'condition' => [
						'select_style' => 'one'
					]
				]
			);
			$this->add_control(
				'number',
				[
					'label' => __( 'Number', 'techtime-elementor-extension' ),
					'type' => Controls_Manager::NUMBER,
					'min' => 1,
					'max' => 100,
					'step' => 1,
					'default' => 1,
				]
			);
			$this->add_control(
				'title',
				[
					'label' => __( 'Title', 'techtime-elementor-extension' ),
					'type' => Controls_Manager::TEXT,
					'default' => __( 'Default title', 'techtime-elementor-extension' ),
					'placeholder' => __( 'Type your title here', 'techtime-elementor-extension' ),
				]
			);
			$this->add_control(
				'description',
				[
					'label' => __( 'Description', 'techtime-elementor-extension' ),
					'type' => Controls_Manager::TEXTAREA,
					'default' => __( 'Default Description', 'techtime-elementor-extension' ),
					'placeholder' => __( 'Type your Description here', 'techtime-elementor-extension' ),
				]
			);
			$this->add_control(
				'icon',
				[
					'label' => __( 'Icon', 'techtime-elementor-extension' ),
					'type' => Controls_Manager::ICONS,
					'default' => [
						'value' => 'fas fa-star',
						'library' => 'solid',
					],
				]
			);
		$this->end_controls_section();

/*
==========
Style Tab
==========
*/

		$this->start_controls_section(
			'general_section',
			[
				'label' => __( 'General', 'techtime-elementor-extension' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
			$this->add_control(
				'select_style',
				[
					'label' => __( 'Select Style', 'techtime-elementor-extension' ),
					'type' => Controls_Manager::SELECT,
					'options' => [
						'one' => __( 'One', 'techtime-elementor-extension' ),
						'two' => __( 'Two', 'techtime-elementor-extension' ),
						'three' => __( 'Three', 'techtime-elementor-extension' ),
						'four' => __( 'Four', 'techtime-elementor-extension' ),
					],
					'default' => 'one',
					
				]
			);
			$this->add_responsive_control(
				'text_align',
				[
					'label' => __( 'Alignment', 'techtime-elementor-extension' ),
					'type' => Controls_Manager::CHOOSE,
					'options' => [
						'left' => [
							'title' => __( 'Left', 'techtime-elementor-extension' ),
							'icon' => 'eicon-text-align-left',
						],
						'center' => [
							'title' => __( 'Center', 'techtime-elementor-extension' ),
							'icon' => 'eicon-text-align-center',
						],
						'right' => [
							'title' => __( 'Right', 'techtime-elementor-extension' ),
							'icon' => 'eicon-text-align-right',
						],
						'justify' => [
							'title' => __( 'Justified', 'techtime-elementor-extension' ),
							'icon' => 'eicon-text-align-justify',
						],
					],
					'selectors' => [
						'{{WRAPPER}} .progress_content' => 'text-align: {{VALUE}};',
					],
				]
			);
		$this->end_controls_section();

		$this->start_controls_section(
			'color_section',
			[
				'label' => __( 'Color', 'techtime-elementor-extension' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
			$this->add_control(
				'color',
				[
					'label' => __( 'Color', 'techtime-elementor-extension' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .work_progress:hover .wrok_process_thumb, .work_progress-number span, .work_progress-number span::before, .work_progress-number span::after, .style-two .work_progress-number span' => 'background: {{VALUE}};',
						'{{WRAPPER}} .work_progress:hover .wrok_process_thumb' => 'border-color: {{VALUE}};',
					],
				]
			);
		$this->end_controls_section();
		
		$this->start_controls_section(
			'title_section_style',
			[
				'label' => __( 'Title & Description', 'techtime-elementor-extension' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
    		$this->add_control(
    			'title_heading',
    			[
    				'label' => __( 'Title', 'techtime-elementor-extension' ),
    				'type' => \Elementor\Controls_Manager::HEADING,
    			]
    		);
    		$this->add_control(
    			'title_color',
    			[
    				'label' => __( 'Color', 'techtime-elementor-extension' ),
    				'type' => \Elementor\Controls_Manager::COLOR,
    				'selectors' => [
    					'{{WRAPPER}} .work_progress .work_progress-title h2' => 'color: {{VALUE}}',
    				],
    			]
    		);
    		$this->add_group_control(
    			\Elementor\Group_Control_Typography::get_type(),
    			[
    				'name' => 'title_typography',
    				'label' => __( 'Typography', 'techtime-elementor-extension' ),
    				'selector' => '{{WRAPPER}} .work_progress .work_progress-title h2',
    			]
    		);
    		$this->add_control(
    			'description_heading',
    			[
    				'label' => __( 'Description', 'techtime-elementor-extension' ),
    				'type' => \Elementor\Controls_Manager::HEADING,
    				'separator' => 'before',
    			]
    		);
    		$this->add_control(
    			'description_color',
    			[
    				'label' => __( 'Color', 'techtime-elementor-extension' ),
    				'type' => \Elementor\Controls_Manager::COLOR,
    				'selectors' => [
    					'{{WRAPPER}} .work_progress .work_progress-desc p' => 'color: {{VALUE}}',
    				],
    			]
    		);
    		$this->add_group_control(
    			\Elementor\Group_Control_Typography::get_type(),
    			[
    				'name' => 'description_typography',
    				'label' => __( 'Typography', 'techtime-elementor-extension' ),
    				'selector' => '{{WRAPPER}} .work_progress .work_progress-desc p',
    			]
    		);
		$this->end_controls_section();
		$this->start_controls_section(
			'icon_section_style',
			[
				'label' => __( 'Icon', 'techtime-elementor-extension' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->start_controls_tabs(
			'style_tabs'
		);
		$this->start_controls_tab(
			'style_normal_tab',
			[
				'label' => __( 'Normal', 'techtime-elementor-extension' ),
			]
		);
			$this->add_control(
				'icon_color',
				[
					'label' => __( 'Icon Color', 'techtime-elementor-extension' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .work_progress_icon i' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_control(
				'icon_background_color',
				[
					'label' => __( 'Background Color', 'techtime-elementor-extension' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .work_progress_icon i' => 'background-color: {{VALUE}};',
					],
				]
			);
			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'icon_border',
					'label' => __( 'Border', 'techtime-elementor-extension' ),
					'selector' => '{{WRAPPER}} .work_progress_icon i',
				]
			);
			$this->add_responsive_control(
				'icon_border_radius',
				[
					'label' => __( 'Border Radius', 'techtime-elementor-extension' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .work_progress_icon i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
			$this->add_responsive_control(
				'icon_margin',
				[
					'label' => __( 'Margin', 'techtime-elementor-extension' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'{{WRAPPER}} .work_progress_icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
					'separator' => 'before',
				]
			);
			$this->add_control(
				'height',
				[
					'label' => __( 'Height', 'techtime-elementor-extension' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .work_progress_icon i' => 'height: {{SIZE}}{{UNIT}};',
					],
				]
			);
			$this->add_control(
				'width',
				[
					'label' => __( 'Width', 'techtime-elementor-extension' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .work_progress_icon i' => 'width: {{SIZE}}{{UNIT}};',
					],
				]
			);

		$this->end_controls_tab();
		$this->start_controls_tab(
				'style_hover_tab',
				[
					'label' => __( 'Hover', 'techtime-elementor-extension' ),
				]
			);

				$this->add_control(
					'icon_hover_color',
					[
						'label' => __( 'Hover Color', 'techtime-elementor-extension' ),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .work_progress_icon i:hover' => 'color: {{VALUE}}',
						],
					]
				);
				$this->add_control(
					'hover_icon_background_color',
					[
						'label' => __( 'Background Color', 'techtime-elementor-extension' ),
						'type' => Controls_Manager::COLOR,
						'default' => '',
						'selectors' => [
							'{{WRAPPER}} .work_progress_icon i:hover' => 'background: {{VALUE}}',
						],
					]
				);
				$this->add_group_control(
					\Elementor\Group_Control_Border::get_type(),
					[
						'name' => 'hover_border',
						'label' => __( 'Hover Border', 'techtime-elementor-extension' ),
						'selector' => '{{WRAPPER}} .work_progress_icon i:hover',
					]
				);
				$this->add_responsive_control(
					'hover_icon_border_radius',
					[
						'label' => __( 'Border Radius', 'techtime-elementor-extension' ),
						'type' => \Elementor\Controls_Manager::DIMENSIONS,
						'size_units' => [ 'px', 'em', '%' ],
						'selectors' => [
							'{{WRAPPER}} .work_progress_icon i:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
						],
					]
				);
			$this->end_controls_tab();
	}

	protected function render() {

		$settings = $this->get_settings_for_display();

		?>

		<?php if($settings['select_style']=='one'){ ?>

		<div class="work_progress default-style">
			<div class="process_thumb">
			   	<img src="<?php echo $settings['image']['url']; ?>" alt="">
				<div class="work_progress-number">
					<span><?php echo $settings['number']; ?></span>
				</div>
			</div>
			<div class="progress_content">

				<div class="work_progress-title">
					<h2>
						<?php echo $settings['title']; ?>
					</h2>
				</div>
				<div class="work_progress-desc">
					<p>
						<?php echo $settings['description']; ?>
					</p>
				</div>
			</div>
			
		</div>

		<?php }elseif($settings['select_style']=='two'){ ?>

		<div class="work_progress style-two">
			
				<div class="work_progress_icon">

					<span><?php \Elementor\Icons_Manager::render_icon( $settings['icon'], [ 'aria-hidden' => 'true' ] ); ?></span>

					<div class="work_progress-number">
						<span><?php echo $settings['number']; ?></span>
					</div>
				</div>			
			
			<div class="progress_content">

				<div class="work_progress-title">
					<h2>
						<?php echo $settings['title']; ?>
					</h2>
				</div>
				<div class="work_progress-desc">
					<p>
						<?php echo $settings['description']; ?>
					</p>
				</div>
			</div><!-- .progress_content -->
		</div>

		<?php }elseif($settings['select_style']=='three'){ ?>

		<div class="work_progress style-three">
			<div class="progress_content">
				<div class="work_progress_icon">
					<span><?php \Elementor\Icons_Manager::render_icon( $settings['icon'], [ 'aria-hidden' => 'true' ] ); ?></span>
				</div>	
				<div class="work_progress-title">
					<h2>
						<?php echo $settings['title']; ?>
					</h2>
				</div>
				<div class="work_progress-desc">
					<p>
						<?php echo $settings['description']; ?>
					</p>
				</div>
			</div><!-- .progress_content -->
		</div>

        <?php }elseif($settings['select_style']=='four'){ ?>
        <div class="work_progress style-four">
			<div class="wrok_process_inner">
				<div class="work_progress-number">
					<span><?php echo $settings['number']; ?></span>
				</div>
    			<div class="progress_content">
    
    				<div class="work_progress-title">
    					<h2>
    						<?php echo $settings['title']; ?>
    					</h2>
    				</div>
    				<div class="work_progress-desc">
    					<p>
    						<?php echo $settings['description']; ?>
    					</p>
    				</div>
			</div>
			</div>
		</div>
		<?php } ?>

		<?php
	}
}